summary refs log tree commit diff
path: root/pkgs
diff options
context:
space:
mode:
authorCorbin Simpson <cds@corbinsimpson.com>2016-01-10 15:33:36 -0800
committerDomen Kožar <domen@dev.si>2016-01-11 20:42:00 +0100
commitda698fd9da2b15ef8f0189afc4ce25e5171b244d (patch)
tree7d7749c3522c1b69f379cb293d1ac2ce2dd245a0 /pkgs
parent685b2ebb60aa7cddedd56736d49ea02ab29e1063 (diff)
downloadnixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar.gz
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar.bz2
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar.lz
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar.xz
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.tar.zst
nixlib-da698fd9da2b15ef8f0189afc4ce25e5171b244d.zip
pypy: add some required build inputs and disable some unsafe tests
I had to disable another networking-centric test suite; it was trying to make
unapproved phone calls.
Diffstat (limited to 'pkgs')
-rw-r--r--pkgs/development/interpreters/pypy/default.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkgs/development/interpreters/pypy/default.nix b/pkgs/development/interpreters/pypy/default.nix
index d95018443879..1edda33a1ae9 100644
--- a/pkgs/development/interpreters/pypy/default.nix
+++ b/pkgs/development/interpreters/pypy/default.nix
@@ -1,6 +1,6 @@
 { stdenv, fetchurl, zlib ? null, zlibSupport ? true, bzip2, pkgconfig, libffi
 , sqlite, openssl, ncurses, pythonFull, expat, tcl, tk, xlibsWrapper, libX11
-, makeWrapper, callPackage, self }:
+, makeWrapper, callPackage, self, gdbm, db }:
 
 assert zlibSupport -> zlib != null;
 
@@ -21,7 +21,7 @@ let
       sha256 = "1g7iipllgdfjgdkypsa1g2pzxgjw9agp40rh82hk31rsbak2hfbl";
     };
 
-    buildInputs = [ bzip2 openssl pkgconfig pythonFull libffi ncurses expat sqlite tk tcl xlibsWrapper libX11 makeWrapper ]
+    buildInputs = [ bzip2 openssl pkgconfig pythonFull libffi ncurses expat sqlite tk tcl xlibsWrapper libX11 makeWrapper gdbm db ]
       ++ stdenv.lib.optional (stdenv ? cc && stdenv.cc.libc != null) stdenv.cc.libc
       ++ stdenv.lib.optional zlibSupport zlib;
 
@@ -81,11 +81,11 @@ let
        # disable sqlite3 due to https://bugs.pypy.org/issue1740
        # disable test_multiprocessing due to transient errors
        # disable test_os because test_urandom_failure fails
        # disable test_urllib2net and test_urllibnet because it requires networking (example.com)
        # disable test_zipfile64 because it randomly timeouts
        # disable test_cpickle because timeouts
        # disable test_ssl because no shared cipher' not found in '[Errno 1] error:14077410:SSL routines:SSL23_GET_SERVER_HELLO:sslv3 alert handshake failure
-      ./pypy-c ./pypy/test_all.py --pypy=./pypy-c -k 'not (test_ssl or test_cpickle or test_sqlite or test_urllib2net or test_urllibnet or test_socket or test_os or test_shutil or test_mhlib or test_multiprocessing or test_zipfile64)' lib-python
+      ./pypy-c ./pypy/test_all.py --pypy=./pypy-c -k 'not (test_ssl or test_cpickle or test_sqlite or test_urllib2net or test_urllibnet or test_urllib2_localnet or test_socket or test_os or test_shutil or test_mhlib or test_multiprocessing or test_zipfile64)' lib-python
     '';
 
     installPhase = ''
@@ -81,11 +81,11 @@ let
        # disable test_multiprocessing due to transient errors
        # disable test_os because test_urandom_failure fails
-       # disable test_urllib2net and test_urllibnet because it requires networking (example.com)
+       # disable test_urllib2net, test_urllib2_localnet, and test_urllibnet because they require networking (example.com)
        # disable test_zipfile64 because it randomly timeouts
        # disable test_cpickle because timeouts